@@ -33,9 +33,6 @@ use 5.008;
 
 use Argonaut::Libraries::Common qw(:ldap :file :config);
 
-use if (USE_LEGACY_JSON_RPC),     'JSON::RPC::Legacy::Client';
-use if not (USE_LEGACY_JSON_RPC), 'JSON::RPC::Client';
-
 my $actions = {
   'ping'                        => 'hostControl_reachable',
   'System.halt'                 => 'hostControl_shutdown',
@@ -57,6 +54,8 @@ my @locked_actions = (
   'OPSI.host_getObjects', 'OPSI.get_netboots', 'OPSI.get_localboots',
 );
 
+my $settings;
+
 sub new
 {
   my ($class) = @_;
@@ -307,7 +306,7 @@ sub reinstall_or_update {
     attrs   => ['fdOpsiNetbootProduct', 'fdOpsiSoftwareList', 'fdOpsiProductProperty']
   );
   if ($mesg->count <= 0) {
-    die "[OPSI] Client with OPSI activated but profile '".$self->{'profile-dn'}."' could not be found";
+    die "[OPSI] Client with OPSI activated but profile '".$settings->{'profile-dn'}."' could not be found";
   }
   $self->{'netboot'}    = ($mesg->entries)[0]->get_value("fdOpsiNetbootProduct");
   $self->{'softlists'}  = ($mesg->entries)[0]->get_value("fdOpsiSoftwareList", asref => 1);
@@ -583,7 +582,7 @@ sub launch {
       $res = $res->result;
       if ((ref $res eq ref {}) && defined $res->{$self->{'fqdn'}}) {
         my $result = $res->{$self->{'fqdn'}};
-        if (JSON::is_bool($result)) {
+        if (JSON::XS::is_bool($result)) {
           $res = $result;
         } elsif (defined $result->{'error'}) {
           $main::log->error("[OPSI] Error : ".$result->{'error'});
